@@ -4,8 +4,8 @@
             var options = {};
             if ($(this).attr('data-date-format') == undefined) {
                 options = { format: "dd-mm-yyyy"};
-            } 
+            }
             $(this).datepicker(options);
         });
     })
-})(jQuery)
+})(jQuery);
